#!/usr/bin/python
# -*-coding: utf-8-*-

import os
import re
import json
import Utils.FileUtils as FileUtils

class LineItem():
	def __init__(self, lineInfo):
		self.init(lineInfo)

	def init(self, lineInfo):
		self.lineInfo = lineInfo
		self.blank = re.findall(r'([\s]*)', self.lineInfo, re.M | re.I)[0]
		self.realLine = self.lineInfo.strip()
		self.addedLineItems = []

	def addAddedLineItem(self, lineItem):
		self.addedLineItems.append(lineItem)
		pass

	def replaceInfo(self, oldInfo, newInfo):
		lineInfo = self.lineInfo.replace(oldInfo, newInfo)
		self.init(lineInfo)

	def setSameLineId(self, lineId):
		self.lineId = lineId

class FileItem():
	def __init__(self, file, logInfo = False):
		self.file = file
		self.logInfo = logInfo
		self.fileData = FileUtils.readFile(self.file)
		self.allLineItems = [LineItem(item) for item in self.fileData.split("\n")]

		allMap = {}

		def setItemLineId(item):
			if(item.realLine not in allMap):
				allMap[item.realLine] = 0
			item.setSameLineId(allMap[item.realLine])
			allMap[item.realLine] = allMap[item.realLine] + 1
			return item

		self.allLineItems = [setItemLineId(item) for item in self.allLineItems]

	def replaceLine(self, oldInfo, newInfo):
		print("==> [FileItem] [replaceLine] ", oldInfo, newInfo)
		for lineItem in self.allLineItems:
			if(oldInfo and newInfo):
				if(oldInfo in lineItem.lineInfo):
					print("==>  [FileItem] [replaceLine] 1:[{}] {} -> {}".format(FileUtils.getFileName(self.file, True), oldInfo, newInfo))
					lineItem.replaceInfo(oldInfo, newInfo)
				# if(self.logInfo and (oldInfo in lineItem.lineInfo)):
				# 	print("==> [FileItem] [replaceLine] 2 : 已包含 {} ".format(newInfo))
		
		self.saveFile()

	def shouldAddLines(self, addedLines, preLine, preLineId):
		if(len(addedLines) <= 0):
			return True;

		firstAddedLine = addedLines[0]
		findLineIdx = len(self.allLineItems)
		for lineIdx in range(0, len(self.allLineItems)):
			lineItem = self.allLineItems[lineIdx]
			if(lineItem.realLine == preLine and lineItem.lineId == preLineId):
				findLineIdx = lineIdx;

		subLineItems = self.allLineItems[findLineIdx:]
		allSubRealLines = [item.realLine for item in subLineItems]

		containsFirstLine = firstAddedLine in allSubRealLines
		shouldAdd = not containsFirstLine
		return shouldAdd

	def addLines(self, addedLines, preLine, preLineId):
		if(not self.shouldAddLines(addedLines, preLine, preLineId)):
			print("==> [FileItem] [addLines] 已包含");
			return;

		for lineIdx in range(0, len(self.allLineItems)):
			lineItem = self.allLineItems[lineIdx]
			if(lineIdx < len(self.allLineItems) - 1):
				nextLineItem = self.allLineItems[lineIdx+1]
				if(len(addedLines) > 0):
					firstAddedLine = addedLines[0]
					if(lineItem.realLine == preLine and lineItem.lineId == preLineId):
						if(nextLineItem.realLine != firstAddedLine):
							for addedLine in addedLines:
								lineInfo = "{}{}".format(lineItem.blank, addedLine)
								lineItem.addAddedLineItem(LineItem(lineInfo))
			else:
				if(lineItem.realLine == preLine and lineItem.lineId == preLineId):
					for addedLine in addedLines:
						lineInfo = "{}{}".format(lineItem.blank, addedLine)
						lineItem.addAddedLineItem(LineItem(lineInfo))

		lineItems = []
		for item in self.allLineItems:
			lineItems.append(item)
			if(len(item.addedLineItems) > 0):
				for addedLineItem in item.addedLineItems:
					lineItems.append(addedLineItem)
					if(self.logInfo):
						print("==> [FileItem] [addLines]: {} -> {}".format(self.file, addedLineItem.lineInfo))
					item.addedLineItems = []

		self.allLineItems = lineItems
		self.saveFile()

	def saveFile(self):
		newFileData = "\n".join([item.lineInfo for item in self.allLineItems])
		FileUtils.writeFile(self.file, newFileData)



import shutil
import os
import time
import json
import sys
import re
import pandas as pd
import subprocess

import Utils.FileUtils as FileUtils

from Normal.ItemInfo import ItemInfo
from SdkAdapter.FileItem import FileItem

class FileContentAdapter():
	def __init__(self, projectFolder):
		self.projectFolder = projectFolder

	def doAdapt(self, adapterFolder, sdkName):
		sdkFileContentAdapterFolder = f"{adapterFolder}/FileContentAdapter"
		excels = FileUtils.getFiles(sdkFileContentAdapterFolder, ".xls")
		sdkFileContentAdapterExcels = [item for item in excels if(FileUtils.getFileName(item, False) == sdkName)]
		if(len(sdkFileContentAdapterExcels) <= 0):
			print(f"\n==> [FileContentAdapter] [doAdapt] not exists: {sdkName}.xls")
			return
		sdkFileContentAdapterExcel = sdkFileContentAdapterExcels[0]

		print("\n==> [FileContentAdapter] [doAdapt] start:", sdkFileContentAdapterExcel)
		configs = FileUtils.readConfigExcel(sdkFileContentAdapterExcel, ["addedLines"])
		for item in configs:
			file = os.path.join(self.projectFolder, item["file"])
			if(not os.path.exists(file)):
				print("\n==> [FileContentAdapter] [doAdapt] file not exists:", file)
				continue;
			fileItem = FileItem(file, logInfo = True)
			newLines = []
			for addLine in item["addedLines"]:
				addLineFile = f"{adapterFolder}/FileContentAdapter/File/{addLine}"
				if(not os.path.exists(addLineFile)):
					print("\n==> [FileContentAdapter] [doAdapt] [addLine]:", addLineFile)
					newLines.append(addLine)
				else:
					print("\n==> [FileContentAdapter] [doAdapt] [addLineFile]:", addLineFile)
					fileData = FileUtils.readFile(addLineFile)
					fileLines = fileData.split("\n")
					for fileLine in fileLines:
						newLines.append(fileLine)

			fileItem.addLines(newLines , item["preLine"], item["preLineId"])
			fileItem.replaceLine(item["toBeReplacedContent"], item["replaceContent"])

		print("==> [FileContentAdapter] [doAdapt] end\n")

	def getFileContentInfos(self, adapterFolder, sdkName):
		fileAdapterFolder = f"{adapterFolder}/FileContentAdapter"
		excels = FileUtils.getFiles(fileAdapterFolder, ".xls")
		sdkFileAdapterExcels = [item for item in excels if(FileUtils.getFileName(item, False) == sdkName)]
		if(len(sdkFileAdapterExcels) <= 0):
			print(f"\n==> [FileAdapter] [getFileContentInfos] not exists: {sdkName}.xls")
			return []

		sdkFileAdapterExcel = sdkFileAdapterExcels[0]
		print("\n==> [FileAdapter] [getFileContentInfos] start")
		sdkConfigInfos = FileUtils.readConfigExcel(sdkFileAdapterExcel, ["addedLines"])
		sdkConfigInfos = [ItemInfo(item) for item in sdkConfigInfos]
		return sdkConfigInfos;








import shutil
import os
import time
import json
import sys
import re
import pandas as pd
import subprocess

import Utils.FileUtils as FileUtils
from Normal.ItemInfo import ItemInfo

class FileAdapter():
	def __init__(self, projectFolder):
		self.projectFolder = projectFolder

	def doAdapt(self, adapterFolder, sdkName):
		fileAdapterFolder = f"{adapterFolder}/FileAdapter"
		excels = FileUtils.getFiles(fileAdapterFolder, ".xls")
		sdkFileAdapterExcels = [item for item in excels if(FileUtils.getFileName(item, False) == sdkName)]
		if(len(sdkFileAdapterExcels) <= 0):
			print(f"\n==> [FileAdapter] [doAdapt] not exists: {sdkName}.xls")
			return

		sdkFileAdapterExcel = sdkFileAdapterExcels[0]
		print("\n==> [FileAdapter] [doAdapt] start")
		sdkConfigInfos = FileUtils.readConfigExcel(sdkFileAdapterExcel, ["sdkPackages"])
		sdkConfigInfos = [ItemInfo(item) for item in sdkConfigInfos]
		for sdkConfigInfo in sdkConfigInfos:
			sdkFolder = f"{adapterFolder}/FileAdapter/File"
			sdkPackages = sdkConfigInfo.sdkPackages
			sdkPackageFolders = [os.path.join(sdkFolder, item) for item in sdkPackages]
			for packageOrFile in sdkPackageFolders:
				print(f"\n==> [FileAdapter] [doAdapt] fileOrFolder: {os.path.abspath(packageOrFile)}")
				if(os.path.isfile(packageOrFile)):
					relPath = os.path.relpath(packageOrFile, sdkFolder)
					newPath = os.path.join(self.projectFolder, relPath)
					print("==> [FileAdapter] [doAdapt] file: " + relPath)
					FileUtils.copyFile(packageOrFile, newPath)
					continue

				allFiles = FileUtils.getFiles(packageOrFile, "", onlyTop = True)
				for file in allFiles:
					relPath = os.path.relpath(file, sdkFolder)
					newPath = os.path.join(self.projectFolder, relPath)
					print("==> [FileAdapter] [doAdapt] fileInFolder: " + relPath)
					FileUtils.copyFile(file, newPath)

		print("\n==> [FileAdapter] [doAdapt] end\n")

	







#!/usr/bin/python
# -*-coding: utf-8-*-

import urllib
import re
import os
import json
import re
import io
import platform
import pandas as pd
import struct
import shutil

def move(src, dest):
	checkCreateFolder(dest)
	shutil.move(src, dest)

def copyFile(srcFile, targetFile):
	targetFileFolder = getFileFolder(targetFile)
	if not os.path.exists(targetFileFolder):
		os.makedirs(targetFileFolder)
	print("==> [FileUtils] [copyFile]:", targetFile)
	shutil.copyfile(srcFile, targetFile)

def checkCopyFile(srcFile, targetFile):
	print("==> [FileUtils] [checkCopyFile]:", targetFile)
	if(os.path.exists(targetFile)):
		return;
	
	copyFile(srcFile, targetFile)

def readInt(datFile, offset):
	allBytes = readBytes(datFile)
	dateBytes = allBytes[offset:offset+4]
	ret = struct.unpack("i", dateBytes)[0]
	return ret

def readBytes(datFile):
	file = open(datFile, "rb")
	allBytes = file.read()
	file.close()
	return allBytes

def writeBytes(datFile, allBytes):
	checkCreateFolder(getFileFolder(datFile))
	if(type(allBytes) == list):
		allBytes = bytearray(allBytes)
	file = open(datFile, "wb")
	file.write(allBytes)
	file.close()

def readConfigExcel(configExcel, parsedKeys = []):
	# print("==> readConfigExcel:", configExcel)
	df1 = pd.read_excel(configExcel, index_col = 0).ffill()
	jsonStr = df1.to_json(orient="records", force_ascii=False)
	tmpConfigs = json.loads(jsonStr)
	for item in tmpConfigs:
		for key in item:
			if(key in parsedKeys):
				item[key] = json.loads(item[key])


	return tmpConfigs

def writeConfigExcel(configExcel, jsonArray):
	dataFrame = pd.DataFrame(jsonArray)
	dataFrame.to_excel(configExcel, encoding='utf-8', index=True, header=True)

def getFileName(file, hasExt = False):
	fsList = get_filePath_fileName_fileExt(file)
	if (hasExt):
		return "{}{}".format(fsList[1], fsList[2])
	else:
		return fsList[1]

def getFileFolder(file):
	fsList = get_filePath_fileName_fileExt(file)
	return fsList[0]

def get_filePath_fileName_fileExt(filename):
		(filepath,tempfilename) = os.path.split(filename);
		(shotname,extension) = os.path.splitext(tempfilename);
		return filepath,shotname,extension;
		
def checkCreateFolder(folder):
	if(not os.path.exists(folder)):
		os.makedirs(folder);

def writeFile(fileName, info):
	checkCreateFolder(getFileFolder(fileName))
	with io.open(fileName, "w", encoding="utf-8") as my_file:
		my_file.write(info)

def readFile(fileName):
	data = "null"
	with io.open(fileName, "r", encoding="utf-8") as myFile:
		data = myFile.read()

	return data;

def getFiles(folder, ext = "", onlyTop = False):
	fileList = []
	for root,folders, files in os.walk(folder):
		isCurrentFolder = os.path.normcase(folder) == os.path.normcase(root)
		fullPathFiles = [os.path.join(root,item) for item in files]
		extFiles = [item for item in fullPathFiles if (ext == "" or item.endswith(ext))]
		if (onlyTop):
			if (isCurrentFolder):
				fileList.extend(extFiles)
		else:
			fileList.extend(extFiles)

	return fileList











import shutil
import os
import time
import json
import sys
import re
import pandas as pd
import subprocess

import Utils.FileUtils as FileUtils
from Normal.ItemInfo import ItemInfo

from SdkAdapter.FileItem import FileItem
from SdkAdapter.FileContentAdapter import FileContentAdapter
from SdkAdapter.FileAdapter import FileAdapter

class SdkAdapter():
	def __init__(self, adapterFolder, projectFolder, sdkName):
		self.projectFolder = projectFolder
		self.adapterFolder = adapterFolder
		self.sdkName = sdkName
		self.sdkAdapterFolder = f"{self.adapterFolder}/SdkAdapter/{self.sdkName}"
		self.sdkAdapterExcel = f"{self.projectFolder}/sdk_configs/{sdkName}/SdkAdapter.xls"
		configSdkAdapterExcel = f"{self.sdkAdapterFolder}/SdkAdapter.xls"
		if(not os.path.exists(self.sdkAdapterExcel)):
			FileUtils.copyFile(configSdkAdapterExcel, self.sdkAdapterExcel)
		self.sdkAdapterInfos = FileUtils.readConfigExcel(self.sdkAdapterExcel)
		self.sdkAdapterInfos = [ItemInfo(item) for item in self.sdkAdapterInfos]

	def doAddSdkFiles(self):
		for sdkAdapterInfo in self.sdkAdapterInfos:
			if(sdkAdapterInfo.isForAdapt):
				sdkName = sdkAdapterInfo.sdkName
				self._doAddSdkFiles(sdkName)
	
	def doChangeSdkLines(self):
		for sdkAdapterInfo in self.sdkAdapterInfos:
			if(sdkAdapterInfo.isForAdapt):
				sdkName = sdkAdapterInfo.sdkName
				self._doChangeSdkLines(sdkName)

	def _doAddSdkFiles(self, sdkName):
		fileAdapter = FileAdapter(self.projectFolder)
		fileAdapter.doAdapt(self.sdkAdapterFolder, sdkName)

	def _doChangeSdkLines(self, sdkName):
		fileContentAdapter = FileContentAdapter(self.projectFolder)
		fileContentAdapter.doAdapt(self.sdkAdapterFolder, sdkName)







import shutil
import os
import time
import json
import sys
import re
import pandas as pd
import subprocess

sys.path.append('D:/work/github/PyTools/packages/tkutils/tkg_utils')
from SdkAdapter.SdkAdapter import SdkAdapter
from SdkInfoAdapter.SdkInfoAdapter import SdkInfoAdapter
from Utils.PrettyFile import PrettyFile
import Utils.FileUtils as FileUtils

#npm install -g --save-dev javascript-obfuscator
class SdkFile():
	def __init__(self, projectFolder):
		self.projectFolder = projectFolder;
		self.sdkFolder = f"{self.projectFolder}/sdk_configs"

		self.facebookSdkFile = "D:/work/github/MiniGamesCracker/FacebookUtils/SdkConfigs/Projects/FacebookSdk/build/web-mobile/assets/main/index.js"
		self.sdkUtilsFile = "D:/work/github/MiniGamesCracker/FacebookUtils/SdkConfigs/Projects/SdkUtils/build/web-mobile/assets/main/index.js"

		self.projectFacebookSdkFile = f"{self.sdkFolder}/tk_sdk_1.js"
		self.projectSdkUtilsFile = f"{self.sdkFolder}/tk_sdk_2.js"


	def doAddSdkFiles(self, obfuscateJsFile, isFB):
		FileUtils.copyFile(self.facebookSdkFile, self.projectFacebookSdkFile)
		if(not isFB):
			FileUtils.copyFile(self.sdkUtilsFile, self.projectSdkUtilsFile)

		if(not obfuscateJsFile):
			return

		self.obfuscateJsScript(self.projectFacebookSdkFile, self.projectFacebookSdkFile)
		if(not isFB):
			self.obfuscateJsScript(self.sdkUtilsFile, self.projectSdkUtilsFile)

	def obfuscateJsScript(self, indexJsFile, jsFile):
		options = {
			"debug-protection":"true",
			# "disable-console-output":"true"
		}
		optionStringList = ["--{} {}".format(item, options[item]) for item in options]
		optionString = " ".join(optionStringList)

		winCmd = 'javascript-obfuscator {} --output {} {}'.format(indexJsFile, jsFile, optionString)
		print(f"==> [obfuscateJsScript], indexJsFile: {indexJsFile}, jsFile: {jsFile}")
		os.system(winCmd)

class AppletAdapter():
	def __init__(self, adapterFolder, projectFolder, sdkName):
		self.adapterFolder = adapterFolder;
		self.projectFolder = projectFolder;
		self.assetFolder = f"{self.projectFolder}/assets"
		self.sdkName = sdkName;
		self.checkCreateAdapterFolders(self.sdkName)

		print("==> [AppletAdapter] [Init] self.adapterFolder:", os.path.abspath(self.adapterFolder))

	def doCollectPictures(self):
		pictureFiles = []
		pictureFiles.extend(FileUtils.getFiles(self.projectFolder, ".jpg"))
		pictureFiles.extend(FileUtils.getFiles(self.projectFolder, ".png"))

		for pictureFile in pictureFiles:
			fileName = FileUtils.getFileName(pictureFile, True)
			newFile = f"{self.projectFolder}/sdk_configs/PictureFiles/{fileName}"
			FileUtils.copyFile(pictureFile, newFile)

	def checkCreateAdapterFolders(self, sdkName):
		subAdapterFolders = [
			"SdkInfoAdapter",
			"SdkAdapter"
		]

		for subAdapterFolder in subAdapterFolders:
			defaultSdkFolder = f"{self.adapterFolder}/{subAdapterFolder}/Default"
			newSdkFolder = f"{self.adapterFolder}/{subAdapterFolder}/{sdkName}"

			files = FileUtils.getFiles(defaultSdkFolder)
			for file in files:
				relFile = os.path.relpath(file, defaultSdkFolder)
				newSdkFile = f"{newSdkFolder}/{relFile}"

				FileUtils.checkCopyFile(file, newSdkFile)

	def doChangeFBInstantToTkSdk(self):
		assetJsFiles = FileUtils.getFiles(self.projectFolder, ".js")
		for assetJsFile in assetJsFiles:
			fileData = FileUtils.readFile(assetJsFile)
			fbInstantReferenceCount = fileData.count("FBInstant")

			for x in range(fbInstantReferenceCount):
				fileData = fileData.replace("FBInstant", "TkSdk")
				pass
			FileUtils.writeFile(assetJsFile, fileData)
			print(f"==> [AppletAdapter] [doChangeFBInstantToTkSdk], fbInstantReferenceCount: {fbInstantReferenceCount:03}, file:{os.path.relpath(assetJsFile, self.projectFolder)}")
		pass

	def doPrettyFiles(self, hasCocos2dJs = False):
		assetFiles = []
		assetFiles.extend(FileUtils.getFiles(self.projectFolder, ".js"))
		assetFiles.extend(FileUtils.getFiles(self.projectFolder, ".json"))
		assetFiles = [item for item in assetFiles if("tk_sdk" not in item)]

		if(not hasCocos2dJs):
			assetFiles = [item for item in assetFiles if("cocos2d" not in item)]

		for assetJsFile in assetFiles:
			prettyFile = PrettyFile(assetJsFile)
			prettyFile.prettyFile()

	def doHookCocosMethod(self):
		assetFiles = []
		assetFiles.extend(FileUtils.getFiles(self.projectFolder, ".js"))
		assetFiles = [item for item in assetFiles if("cocos2d" in item)]
		addLines = [
			# CocosAddLine("._instantiate(null, !0)", -1, "window.HookUtils && window.HookUtils.onNodeInstantiate && window.HookUtils.onNodeInstantiate(arguments);"),
			# CocosAddLine("this._super(), this._removeGraphics()", 0, "window.HookUtils && window.HookUtils.onNodeDestroy && window.HookUtils.onNodeDestroy(this.node);"),
			CocosAddLine('.emit("active-in-hierarchy-changed"', 0, "window.HookUtils && window.HookUtils.onNodeActive && window.HookUtils.onNodeActive(arguments[0],arguments[1]);")
		]

		for assetJsFile in assetFiles:
			for addLine in addLines:
				fileData = FileUtils.readFile(assetJsFile)
				fileLines = fileData.split("\n")
				tagLineComps = [(addLine.tagLine in item) for item in fileLines]
				tagLineIndex = tagLineComps.index(True)

				insertLineComps = [item for item in fileLines if(addLine.insertLine in item)]
				hasInsertLineInFileData = len(insertLineComps) > 0

				if(hasInsertLineInFileData):
					continue;

				insertLineIndex = tagLineIndex + addLine.offsetLineIndex
				fileLines.insert(insertLineIndex, addLine.insertLine)
				FileUtils.writeFile(assetJsFile, "\n".join(fileLines))
				print("==> [AppletAdapter] [doHookCocosMethod]:" + json.dumps(addLine.__dict__, indent = 4))

	def doUglyFiles(self):
		assetFiles = []
		assetFiles.extend(FileUtils.getFiles(self.assetFolder, ".js"))

		for assetJsFile in assetFiles:
			prettyFile = PrettyFile(assetJsFile)
			prettyFile.doUglyFile()

	def doAdaptSdk(self):
		sdkAdapter = SdkAdapter(self.adapterFolder, self.projectFolder, self.sdkName)
		sdkAdapter.doAddSdkFiles()
		sdkAdapter.doChangeSdkLines()

	def doChangeSdkInfos(self):
		sdkInfoAdapter = SdkInfoAdapter(self.adapterFolder, self.projectFolder, self.sdkName)
		sdkInfoAdapter.doChangeSdkInfos()

	def doAddSdkFiles(self, obfuscateJsFile, isFB):
		sdkFile = SdkFile(self.projectFolder)
		sdkFile.doAddSdkFiles(obfuscateJsFile, isFB)



class CocosAddLine():
	def __init__(self, tagLine, offsetLineIndex, insertLine):
		self.tagLine = tagLine
		self.offsetLineIndex = offsetLineIndex
		self.insertLine = insertLine








#!/usr/bin/python
# -*-coding: utf-8-*-

import jsbeautifier
import json
import Utils.FileUtils as FileUtils

class PrettyFile():
	def __init__(self, assetFile):
		self.assetFile = assetFile

	def doUglyFile(self):
		if(not self.assetFile.endswith(".js")):
			return

		print("==> [PrettyFile] [uglyFile]", self.assetFile)
		options = {
			"eol": "",
		    "indent_size": 0
		}
		jsData = FileUtils.readFile(self.assetFile)
		newJsData = jsbeautifier.beautify(jsData, options)
		FileUtils.writeFile(self.assetFile, newJsData)

	def prettyFile(self):
		# self.doPrettyJsonFile()
		self.doPrettyJavaScriptFile()
		self.doPrettyHtmlFile()
		pass

	def doPrettyJsonFile(self):
		if(not self.assetFile.endswith(".json")):
			return

		print("==> [PrettyFile] [doPrettyJsonFile]", self.assetFile)
		jsonData = FileUtils.readFile(self.assetFile)
		jsonMap = json.loads(jsonData)
		newData = json.dumps(jsonMap, indent = 4, ensure_ascii = False)
		FileUtils.writeFile(self.assetFile, newData)

	def doPrettyJavaScriptFile(self):
		if(not self.assetFile.endswith(".js")):
			return

		print("==> [PrettyFile] [doPrettyJavaScriptFile]", self.assetFile)
		jsData = FileUtils.readFile(self.assetFile)
		newJsData = jsbeautifier.beautify(jsData)
		FileUtils.writeFile(self.assetFile, newJsData)


	def doPrettyHtmlFile(self):
		if(not self.assetFile.endswith(".html")):
			return

		print("==> [PrettyFile] [doPrettyHtmlFile]", self.assetFile)
		jsData = FileUtils.readFile(self.assetFile)
		newJsData = jsbeautifier.beautify(jsData)
		FileUtils.writeFile(self.assetFile, newJsData)

		




from setuptools import setup

setup(name='tkg_utils',
      version='2.0.3',
      description='tkg_utils',
      url='https://github.com/BigDataFounder/tkg_utils',
      author='gengch',
      author_email='gengchuanhua@163.com',
      license='MIT',
      packages=['tkg_utils', "tkg_utils/Normal", "tkg_utils/SdkAdapter", "tkg_utils/Utils"])
